module.exports = defineTest({
	description: 'Properly renders conditionals in hoisted variables in dead branches'
});
